OiRA

# OiRA@Daimler

OiRA - Valutazzjoni tar-Riskji Onlajn Interattiva (Online interactive Risk Assessment)

## L-evalwazzjonijiet tar-riskju tiegħi

Filters

Close

Hide archived risk assessments

Agħżel sessjoni preċedenti biex tlesti jew tirrevedi jew ibda sessjoni ġdida.

- #### Private Security, Grafton Street

  Mibdi 5 May 2019

  More

- #### Commercial guarding, Leicester

  Mibdi 6 March 2020

  More

## Għodod tal-OiRA disponibbli

EU Cleaning EU Hairdressing EU Live Performance - Productions Leather and Tanning Maritime Transport Private Security

Back

## index-logged-in.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More